@@ -1,5 +1,6 @@
 from rest_framework.routers import DefaultRouter
 from bluedot_rest_framework import import_string
+from bluedot_rest_framework.event.live.views import EventLivePPTCurrentView
 
 EventView = import_string('event.views')
 EventQuestionView = import_string('event.question.views')
@@ -17,6 +18,8 @@ EventVenueView = import_string('event.venue.views')
 EventRegisterConfigView = import_string('event.register.config_views')
 
 router = DefaultRouter(trailing_slash=False)
+router.register(r'event/live/ppt/current', EventLivePPTCurrentView,
+                basename='event-live-ppt-current')
 router.register(r'event/vote/user', EventVoteUserView,
                 basename='event-vote-user')
 router.register(r'event/venue', EventVenueView,
