@@ -11,6 +11,7 @@ class WeChatUserSet:
     appid = ''
     openid = ''
 
+
     user_data = None  # 用户信息
     wechat_user_queryset = None  # WeChatUser QuerySet
 
@@ -26,7 +27,8 @@ class WeChatUserSet:
                     'province': user_info.get('province', ''),
                     'city': user_info.get('city', ''),
                     'country': user_info.get('country', ''),
-                    'language': user_info.get('language', '')
+                    'language': user_info.get('language', ''),
+                    
                 }
                 self.openid = user_info.get('openid', '')
                 self.wechat_user_queryset = WeChatUser.objects.filter(
@@ -77,9 +79,10 @@ class WeChatUserSet:
             self.update_user()
         else:
             self.create_user()
-    def handle_subscribe(self,subscribe):
+    def handle_subscribe(self, subscribe):
         if self.wechat_user_queryset:
-            self.wechat_user_queryset.subscribe=subscribe
+            self.wechat_user_queryset.subscribe = subscribe
+            self.wechat_user_queryset.save()
  
     def get_token(self):
         token = ''
