@@ -79,8 +79,12 @@ class Response(APIView):
 
         elif msg.type == 'event':
             if msg_dict['Event'] == 'unsubscribe':
-                WeChatUserSet(
-                    openid=msg_dict['FromUserName']).handle_subscribe(0)
+                openid = openid = msg_dict['FromUserName']
+                open_queryset = WeChatUserOpenid.objects.filter(
+                    openid=openid).first()
+                open_queryset.subscribe = 0
+                open_queryset.save()
+
             elif msg_dict['Event'] == 'SCAN' or msg_dict['Event'] == 'subscribe_scan':
                 queryset = WeChatResponseEvent.objects.filter(
                     event_key=msg_dict['EventKey']).first()
@@ -92,8 +96,11 @@ class Response(APIView):
                     self.perform_event(msg_dict)
 
             if 'subscribe' in msg_dict['Event']:
-                WeChatUserSet(
-                    openid=msg_dict['FromUserName']).handle_subscribe(1)
+                openid = openid = msg_dict['FromUserName']
+                open_queryset = WeChatUserOpenid.objects.filter(
+                    openid=openid).first()
+                open_queryset.subscribe = 1
+                open_queryset.save()
 
         reply = create_reply(self.reply_text, msg)
         response = HttpResponse(
